@@ -1028,6 +1028,34 @@ class CkafkaClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def SendMessage(self, request):
+        """This API is used to send messages through the HTTP access layer.
+
+        :param request: Request instance for SendMessage.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.SendMessageRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.SendMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SendMessage", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SendMessageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
